@@ -16,12 +16,31 @@ The six Chess pieces, in various languages.
 
 =head1 CONTRIBUTOR
 
-Abigail.
+Abigail
 
-Introduced in Acme-MetaSyntactic version 0.59, published on January 30, 2006.
+=head1 CHANGES
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=over 4
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2006-01-30
+
+Introduced in Acme-MetaSyntactic version 0.59.
+
+=item *
+
+2005-10-26
+
+Submitted by Abigail.
+
+=back
 
 =head1 SEE ALSO
 
