@@ -1,7 +1,7 @@
 package Acme::MetaSyntactic::good_omens;
 use strict;
 use Acme::MetaSyntactic::List;
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 our @ISA = qw( Acme::MetaSyntactic::List );
 
 =head1 NAME
@@ -192,12 +192,27 @@ __END__
 
 Jean Forget.
 
+=head1 IN MEMORIAM
+
+This theme is dedicated to Terry Pratchett (1948-2015)
+
+  One day I'll be dead and THEN you'll all be sorry.
+  -- (Terry Pratchett, 28 Nov 1992, on alt.fan.pratchett)
+
+
 =head1 CHANGES
 
 =over 4
 
 =item *
 
+2016-06-08 - v1.001
+
+Updated with L<IN MEMORIAM> after the passing of Sir Terry Pratchett
+on March 12, 2015. Published in Acme-MetaSyntactic-Themes version 1.046.
+
+=item *
+
 2012-05-07 - v1.000
 
 Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
