@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::linux;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.036';
+our $VERSION = '1.037';
 
 our %Remote = (
     source  => 'http://distrowatch.com/',
@@ -48,6 +48,12 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2026-01-12 - v1.037
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.056.
+
+=item *
+
 2021-04-30 - v1.036
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.055.
@@ -315,189 +321,287 @@ __DATA__
 # names
 ThreeCX
 FourMLinux
-Absolute
-AcademiX
+Accessible_Coconut
+AcorOS
+AcreetionOS
+Adelie
+Aeon
+AerynOS
+AgarimOS
+Alien_OS
 AlmaLinux
 Alpine
 ALT
-Anarchy
-Android_x86
+AlterOS
+AnduinOS
 antiX
-APODIO
+AnuBitux
+AOSC
 Arch
-ArchBang
-ArchLabs
+ArchBANG
+Archcraft
 Archman
-ArchStrike
-ArcoLinux
+Archriot
+arcOS
+Arkane
+Armbian
 Artix
-Arya
-Asianux
+Asahi
+Asmi
+Astra
+Athena
+ATZ_Linux
+Aurora
+AUSTRUMI
 AV_Linux
+AxOS
 BackBox
-Baltix
-Baruwa
-batocera
+Batocera
+Bazzite
 Bedrock
-BEE_free
 Berry
+Berserk_Arch
+Besgnulinux
 Bicom
 BigLinux
-BlackArch
-blackPanther
+Blade
+blendOS
+Bluefin
 BlueOnyx
 Bluestar
 Bodhi
 BOSS
+Br_OS
+BRGV_OS
 BSDRP
 BunsenLabs
-CAELinux
+CachyOS
 CAINE
+Calam
 Calculate
 Canaima
+Catbird
 CentOS
-Clear
-ClearOS
+Chimera
+ChromeOS
+Circle
+Clear_NDR
 Clonezilla
-ClonOS
-CloudReady
+CloudLinux
+Commodore
+CROWZ
+Crunchbangplusplus
 CRUX
+CuerdOS
+d77void
+Damn_Small
 Daphile
+DAT
 Debian
 Debian_Edu
+DebLight
 deepin
+DEKUVE
+DESERT
 Devuan
-Diamond
 DietPi
+Ditana
+Dr_Parted
 DragonFly
-Dragora
-DRBL
-EasyNAS
+DragonOS
+Drauger
+Dynebolic
+DynFi
 EasyOS
-Elastix
+Edubuntu
+ELEGANCE
 elementary
 Elive
+ElysiaOS
 Emmabuntus
+EN_OS
 EndeavourOS
-Endian
 Endless
-Enso
-EuroLinux
+Escuelas
+EterTICs
 Exe
 Exherbo
+Expirion
 ExTiX
+Exton
+extrox
 Fatdog64
 Fedora
 Feren
 Finnix
-ForLEx
+Flatcar
+Flora
+Fluxuan
 FreeBSD
 FreedomBox
-FreePBX
-Freespire
+Freeduc
+Freeloader
 FuguIta
-Funtoo
+FunOS
+FUSS
+FydeOS
+gabeeOSLinux
 Garuda
-Gecko
-GeeXboX
 Gentoo
 GhostBSD
+GLF
+GNOME_OS
+Gnoppix
+Gnuinos
 GoboLinux
+Gooroom
 GParted
-Greenie
+GrapheneOS
+Green
 Grml
+GuideOS
 Guix_System
+GXDE
+HackerOS
 Haiku
 HamoniKR
-Hanthana
 HardenedBSD
+HeliumOS
+Huayra
+HydraPWK
 Hyperbola
+iDeal
+iodeOS
 IPFire
-JingOS
 Kali
+Kamarada
 KANOTIX
 KaOS
-Karoshi
+KDE_Linux
 KDE_neon
-KNOPPIX
+Kicksecure
+Kiro
 Kodachi
 KolibriOS
 Kubuntu
+Kumander
 Kwort
+LainOS
 Lakka
+LangitKetujuh
+LazyLinux
+Lernstick
 LFS
+LibraZiK
 LibreELEC
-LinHES
-Linspire
+Lingmo
+Linux_Schools
+LinuxCNC
 LinuxConsole
 Linuxfx
+LinuxHub
 Lite
 Live_Raizo
+Liya
 LliureX
+Loc_OS
+Luberri
 Lubuntu
-LuninuX
-LXLE
+LxPup
 Mabox
+Macaroni
+Maemo_Leste
 Mageia
+MagOS
+mAid
 MakuluLinux
 Manjaro
+Mauna
+MAX
+Melawy
 MidnightBSD
+Milis
+MiniOS
 Mint
-MLL
+MIRACLE
+Mobian
+MocaccinoOS
+MODICIA
+MODOS
+Murena
 MX_Linux
+nakeDeb
+NebiOS
+Nemesis
 Neptune
 NetBSD
+NethSecurity
 NethServer
 Netrunner
 NexentaStor
 Nitrux
 NixOS
+Nobara
+Noid
 NomadBSD
 NST
 NuTyX
-OB2D
+Nyarch
 Obarun
-OLPC
-Omarine
-Omoikane
+ObsidianOS
+Omarchy
+OmegaLinux
+OmniOS
 OpenBSD
+openEuler
 OpenIndiana
+openKylin
 openmamba
 OpenMandriva
 OpenMediaVault
 openSUSE
 OPNsense
 Oracle
-OSGeoLive
+Oreon
+OSINT_VM
 OSMC
+OsoLinux
 OviOS
 PakOS
 paldo
 Parabola
+Parch
 Pardus
 Parrot
 Parted_Magic
 PCLinuxOS
 Pearl
+pearOS
+PelicanHPC
 Pentoo
 Peppermint
+Peropesis
 pfSense
-Photon
-Pinguy
+PikaOS
 Pisi
 Plamo
+Planeta_Tecno
 PLD
 Plop
 Pop_OS
 Porteus
 Porteus_Kiosk
+PorteuX
+postmarketOS
+Predator_OS
 PrimTux
 Proxmox
 Puppy
-PureOS
 Q4OS
+Qlustar
+Quarkos
 Qubes
-RancherOS
+Quirinux
 RasPiOS
 RDS
 ReactOS
@@ -505,30 +609,39 @@ RebeccaBlackOS
 RebornOS
 Recalbox
 Red_Hat
+RED_OS
 Redcore
-Redo
+Redox
 Refracta
+RefreshOS
 Regata
-REMnux
-Rescatux
+RELIANOID
 Rescuezilla
+Rhino
 RISC
-Robolinux
-Rocks_Cluster
+rlxos
+Rockstor
+Rocky
 ROSA
 RSS
 Runtu
-Sabayon
-Salient
-Scientific
-Securepoint
-SELKS
-Septor
+Salix
+Sculpt
+SDesk
+Secure_K
+secureblue
+Security_Onion
+Serbian
+Shanios
+Shebang
+Side
 siduction
-Simplicity
+Skudonet
+Skywave
 Slackel
 Slackware
-Slax
+Slimbook_OS
+Slint
 SliTaz
 SmartOS
 SME_Server
@@ -537,55 +650,85 @@ Snal
 Solaris
 Solus
 SolydXK
-Sophos
-Source_Mage
+Soplos
 SparkyLinux
-Springdale
-Star
+spirit_OS
+StartOS
 SteamOS
+StormOS
+StratOS
 Super_Grub2
-SuperGamer
-SuperX
 SUSE
-Swift
+Synex
+SysLinuxOS
 SystemRescue
-T2
+T2_Linux
 Tails
-TENS
+Talos
+TeaLinux
 Thinstation
+TileOS
 Tiny_Core
-ToOpPy
-Trident
+TobbeOS
+Tribblix
 Trisquel
+TROMjaro
 TrueNAS
+Tsurugi
+TTOS
 TurnKey
-tuxtrans
+TUXEDO
+Twister
+UBLinux
 UBOS
 UBports
 Ubuntu
 Ubuntu_Budgie
-Ubuntu_DP
+Ubuntu_Cinnamon
 Ubuntu_Kylin
 Ubuntu_MATE
+Ubuntu_Pack
 Ubuntu_Studio
+Ubuntu_Sway
+Ubuntu_Unity
 Ufficio_Zero
 Ultimate
+Ultramarine
+umbrelOS
+Uncom
 Univention
-Untangle
-Uruk
+Unraid
+UOS
+VailuxOS
+Vanilla
+Vendefoul
 Venom
+Ventoy
+Vinari
+Vincent
 Vine
+Vipnix
+Vitalinux
 Void
 Volumio
 Voyager
 VyOS
-Webconverger
+wattOS
 Whonix
 Wifislax
+WM_Live
+XCP_ng
+Xebian
+XeroLinux
 XigmaNAS
+Ximper
+XIVA_Studio
+Xray_OS
 Xubuntu
 YunoHost
+Zenned
 Zentyal
 Zenwalk
-Zevenet
+Zephix
+ZimaOS
 Zorin
