@@ -6,6 +6,8 @@ our $VERSION = '1.000';
 __PACKAGE__->init();
 1;
 
+=encoding iso-8859-1
+
 =head1 NAME
 
 Acme::MetaSyntactic::pooh - The characters from I<Winnie-the-Pooh> theme
@@ -25,17 +27,49 @@ I<Winnie-the-Pooh> is the correct spelling, no matter what Disney says.
 
 =head1 CONTRIBUTORS
 
-Original contributor: Abigail (late October 2005)
+Abigail, Lon Brocard.
 
-Proposed independently a week later (early November 2005) by Leon Brocard,
-with a few additions.
+=head1 CHANGES
 
-Introduced in Acme-MetaSyntactic version 0.61, published on February 13, 2006.
+=over 4
 
-Updated in version 0.64, published on March 6, 2006.
+=item *
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2006-03-06
+
+Updated in Acme-MetaSyntactic version 0.64.
+
+=item *
+
+2006-02-16
+
+Abigail sent a patch with a few additions.
+
+=item *
+
+2006-02-13
+
+Introduced in Acme-MetaSyntactic version 0.61.
+
+=item *
+
+2005-11-03
+
+Submitted independently by Leon Brocard, with a few additions.
+
+=item *
+
+2005-10-27
+
+Submitted by Abigail.
+
+=back
 
 =head1 SEE ALSO
 
